This is a template for making a pull-request. You can remove the text and sections and write your own thing if you wish, just make sure you give enough information about how and why. If you have any issues or difficulties, don't hesitate to open an issue.


# Description

The aim is to add this feature ...

# Proposed Changes

I changed the `foo()` function so that ...


# Checklist

Here are some things to check before creating the pull request. If you encounter any issues, don't hesitate to ask for help :)

- [ ] I have read the [contributor's guide](https://github.com/arnab39/reptrix/blob/main/CONTRIBUTING.md).
- [ ] The base branch of my pull request is the `dev` branch, not the `main` branch.
- [ ] I ran the [code checks](https://github.com/arnab39/reptrix/blob/main/CONTRIBUTING.md#implement-your-changes) on the files I added or modified and fixed the errors.
- [ ] I updated the [changelog](https://github.com/arnab39/reptrix/blob/main/CHANGELOG.md).
